/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

rootProject.name = "iggy-java-sdk"

include("iggy")
project(":iggy").projectDir = file("java-sdk")

// External processors - Stream processing integrations
include("iggy-connector-library")
project(":iggy-connector-library").projectDir = file("external-processors/iggy-connector-flink/iggy-connector-library")

include("iggy-flink-examples")
project(":iggy-flink-examples").projectDir = file("external-processors/iggy-connector-flink/iggy-flink-examples")

include("iggy-connector-pinot")
project(":iggy-connector-pinot").projectDir = file("external-processors/iggy-connector-pinot")
